def few_shot(prompt, chains):
    
    few_shot_prompt = prompt + "\n\n"
    
    for chain in chains:
        few_shot_prompt += "Chain:" + "\n"
        few_shot_prompt += "Character: {}\n".format(chain["character"])
        few_shot_prompt += "Setting: {}\n".format(chain["setting"])
        few_shot_prompt += "Question: {}\n".format(chain["question"])
        few_shot_prompt += "Answer: {}\n".format(chain["answer"])
    
    return few_shot_prompt

"""
The chains object is a list that contains multiple chain objects. Each chain object represents a prompt chain with the character, setting, question, and answer.

Example execution

prompt = "I want to write a story. Please help me come up with some ideas. Start with a character and a setting."

chains = [
    {
        "character": "A detective",
        "setting": "A small town",
        "question": "What is the detective's first impression of the town?",
        "answer": "The detective is struck by how quiet and peaceful the town seems on the surface, despite the fact that there is clearly something sinister lurking beneath the surface."
    },
    {
        "character": "The town's mayor",
        "setting": "The mayor's office",
        "question": "What is the mayor's greatest fear?",
        "answer": "The mayor is terrified of being exposed as a fraud, and will stop at nothing to protect his reputation and maintain his grip on power."
    },
    {
        "character": "The owner of the local diner",
        "setting": "The diner",
        "question": "What is the owner's relationship with the town's residents like?",
        "answer": "The owner of the diner is well-liked by most of the residents, but has a strained relationship with one of the families involved in the long-standing feud that is tearing the town apart."
    }
]

few_shot_prompt = generate_few_shot_prompt(prompt, chains)

print(few_shot_prompt)
"""


def template(input:str = "") -> tuple[str,str]:
    prompt:str = f"{input}, "
    negative_prompt:str = " "
    return prompt, negative_prompt

def portrait_animated_disney(input:str = "elsa") -> tuple[str,str]:
    
    prompt:str = f"{input}, d & d, fantasy, intricate, elegant, highly detailed, digital painting, artstation, concept art, matte, sharp focus, illustration, art by artgerm, greg rutkowski, alphonse mucha, 8k"
    
    negative_prompt:str = "deformed, cripple, ugly, additional arms, additional legs, additional head, two heads, multiple people, group of people"
    
    return prompt, negative_prompt

def portrait_art_lineart(input:str = "strong warrior princess") -> tuple[str,str]:
    
    prompt:str = f"{input}, portrait | centered| key visual| intricate| highly detailed| breathtaking beauty| precise lineart| vibrant| comprehensive cinematic| Carne Griffiths| Conrad Roset"
    
    negative_prompt:str = " "
    
    return prompt, negative_prompt

def portrait_photorealistic_female_snow(input: str = "gorgeous Norwegian girl in winter clothing with long wavy blonde hair") -> tuple[str, str]:
    
    prompt: str = f"professional portrait photograph of a {input}, ((sultry flirty look)), freckles, beautiful symmetrical face, cute natural makeup, ((standing outside in snowy city street)), stunning modern urban upscale environment, ultra realistic, concept art, elegant, highly detailed, intricate, sharp focus, depth of field, f/1. 8, 85mm, medium shot, mid shot, (centered image composition), (professionally color graded), ((bright soft diffused light)), volumetric fog, trending on instagram, trending on tumblr, hdr 4k, 8k"
    
    negative_prompt: str = "(bonnet), (hat), (beanie), cap, (((wide shot))), (cropped head), bad framing, out of frame, deformed, cripple, old, fat, ugly, poor, missing arm, additional arms, additional legs, additional head, additional face, multiple people, group of people, dyed hair, black and white, grayscale"
    
    return prompt, negative_prompt

def portrait_photorealistic_korean_woman(input:str = "") -> tuple[str,str]:
    
    prompt:str = f"{input}, (masterpiece:1. 0), (best quality:1. 4), (ultra highres:1. 2), (photorealistic:1. 4), (8k, RAW photo:1. 2), (soft focus:1. 4), 1 woman, posh, (sharp focus:1. 4), (korean:1. 2), (american:1. 1), detailed beautiful face, black hair, (detailed open blazer:1. 4), tie, beautiful white shiny humid skin, smiling"
    
    negative_prompt:str = "illustration, 3d, sepia, painting, cartoons, sketch, (worst quality:2), (low quality:2), (normal quality:2), lowres, bad anatomy, bad hands, normal quality, ((monochrome)), ((grayscale:1.2)),newhalf, collapsed eyeshadow, multiple eyebrows, pink hair, analog, analogphoto"
    
    return prompt, negative_prompt

def portrait_photorealistic_white_woman(input:str = "a few freckles, round eyes and short messy hair") -> tuple[str,str]:
    
    prompt:str = f"detailed and realistic portrait of a woman with {input} outside, wearing a white t shirt, staring at camera, chapped lips, soft natural lighting, portrait photography, magical photography, dramatic lighting, photo realism, ultra-detailed, intimate portrait composition, Leica 50mm, f1. 4"
    
    negative_prompt:str = " "
    
    return prompt, negative_prompt

def portrait_art_19thcenturypainting(input:str = "old coal miner") -> tuple[str,str]:
    
    prompt:str = f", a portrait of an {input} in 19th century, beautiful painting with highly detailed face by greg rutkowski and magali villanueve"
    
    negative_prompt:str = " "
    
    return prompt, negative_prompt

def portrait_art_bwpainting(input:str = "pierce brisnan as old sailor") -> tuple[str,str]:
    
    prompt:str = f"highly detailed portrait of {input}, by Dustin Nguyen, Akihiko Yoshida, Greg Tocchini, Greg Rutkowski, Cliff Chiang, 4k resolution, Dishonored inspired, bravely default inspired, vibrant but dreary red, black and white color scheme! ! ! , epic extreme long shot, dark mood and strong backlighting, volumetric lights, smoke volutes, artstation HQ, unreal engine, octane renderer, HQ, 8K"
    
    negative_prompt:str = " "
    
    return prompt, negative_prompt

def portrait_art_solarpunk(input:str = "asian girl") -> tuple[str,str]:
    
    prompt:str = f"Beautiful anime portrait painting of {input}, solarpunk summer chill day, by tim okamura, victor nizovtsev, greg rutkowski, noah bradley. trending on artstation, 8k, masterpiece, graffiti paint, fine detail, full of color, intricate detail, golden ratio illustration"
    
    negative_prompt:str = " "
    
    return prompt, negative_prompt

def landscape_animated_cyberpunk(input:str = "streets") -> tuple[str,str]:
    
    prompt:str = f"portrait art of blade runner {input} 8 k ultra realistic, lens flare, atmosphere, glow, detailed, intricate, full of colour, cinematic lighting, trending on artstation, 4 k, hyperrealistic, focused, extreme details, unreal engine 5, cinematic, masterpiece"
    
    negative_prompt:str = " "
    
    return prompt, negative_prompt

def portrait_art_anime(input:str = "warrior goddess standing alone on hill") -> tuple[str,str]:
    prompt:str = f"poster of {input} | centered| detailed gorgeous face| anime style| key visual| intricate detail| highly detailed| breathtaking| vibrant| panoramic| cinematic| Carne Griffiths| Conrad Roset| Makoto Shinkai"
    
    negative_prompt:str = "no words| watermark| bad anatomy| blurry| fuzzy| extra legs| extra arms| extra fingers| poorly drawn hands| poorly drawn feet| disfigured| out of frame| tiling| bad art| deformed| mutated| double face"
    
    return prompt, negative_prompt

def portrait_art_personification(persona:str = "the Halloween holiday", character:str ="a cute girl with short hair and a villain's smile") -> tuple[str,str]:
    
    prompt:str = f"The personification of {input} in the form of {input}, (((cute girl)))cute hats, cute cheeks, unreal engine, highly detailed, artgerm digital illustration, woo tooth, studio ghibli, deviantart, sharp focus, artstation, by Alexei Vinogradov bakery, sweets, emerald eyes"
    
    negative_prompt:str = "bad anatomy, extra legs, extra arms, poorly drawn face, poorly drawn hands, poorly drawn feet, fat, disfigured, out of frame, long neck, poo art, bad hands, bad art, deformed, gun, double head, flowers, asian, hyperrealistic, child"
    
    return prompt, negative_prompt

def portrait_photorealistic_fullbody(input:str = "paladin wearing full body (light silver armour:1. 2)") -> tuple[str,str]:
    
    prompt:str = f"full body, walking pose, slow motion, {input}, (insanely detailed, bloom:1. 5), (highest quality, Alessandro Casagrande, Greg Rutkowski, Sally Mann, concept art, 4k), (analog:1. 2), (high sharpness), (detailed pupils:1. 1), (painting:1. 1), (digital painting:1. 1), detailed face and eyes, Masterpiece, best quality, (highly detailed photo:1. 1), 8k, photorealistic, (long blonde Hair, ponytail haircut, ecstatic:1. 1), (young woman:1. 1), By jeremy mann, by sandra chevrier, by maciej kuciara, sharp, (perfect body:1. 1), realistic, real shadow, 3d, (temple background:1. 2), (by Michelangelo)"
    
    negative_prompt:str = "jpeg artifacts, low quality, lowres, 3d, render, doll, plastic, blur, haze, monochrome, b&w, text, (ugly:1.2), unclear eyes, no arms, bad anatomy, cropped, censoring, asymmetric eyes, bad anatomy, bad proportions, cropped, cross-eyed, deformed, extra arms, extra fingers, extra limbs, fused fingers, malformed, mangled hands, misshapen body, missing arms, missing fingers, missing hands, missing legs, poorly drawn, tentacle finger, too many arms, too many fingers, watermark, logo, text, letters, signature, username, words, blurry, cropped"
    
    return prompt, negative_prompt

def portrait_animated_tarot(input:str = "cyberpunk head") -> tuple[str,str]:
    prompt:str = f"((tarot card with intricate detailed frame around the outside)) | side profile of {input} with large moon in background| cyberpunk | styled in Art Nouveau | insanely detailed | embellishments | high definition | concept art | digital art | vibrant"
    negative_prompt:str = "lowres| text| error| missing fingers| extra digit| fewer digits| cropped| (worst quality| low quality:1.4)| jpeg artifacts| signature| bad anatomy| extra legs| extra arms| extra fingers| poorly drawn hands| poorly drawn feet| disfigured| out of frame| tiling| bad art| deformed| mutated| blurry| fuzzy| misshaped| mutant| gross| disgusting| ugly| watermark| watermarks"
    return prompt, negative_prompt

def anime_spacegirl(input:str = "") -> tuple[str,str]:
    
    prompt:str = f"{input}, space girl| standing alone on hill| centered| detailed gorgeous face| anime style| key visual| intricate detail| highly detailed| breathtaking| vibrant| panoramic| cinematic| Carne Griffiths| Conrad Roset| ghibli"
    
    negative_prompt:str = "deformed, cripple, ugly, additional arms, additional legs, additional head, two heads, multiple people, group of people"
    
    return prompt, negative_prompt

def anime_model_racecar(input:str = "") -> tuple[str,str]:
    
    prompt:str = f"{input}, modelshoot style, (film stock), (film grain), (extremely detailed CG unity 8k wallpaper), full body portrait of the most beautiful woman in the world, (cowboy shot), beautiful racecar woman standing in front of a race car, standing, tanned skin, (blush) (bangs), long hair, (freckles:0. 75), detailed symmetrical face, smirk, ((pink hair:1. 4)), (straight hair), (green eyes:1. 3), reflective eyes, dark eyebrows, mascara, makeup, (dark lipstick), (white sclera), dust particles, detailed lighting, rim lighting, dramatic lighting, chiaroscuro, (black crop top), ((white racing jacket)), open jacket, (white yoga pants), race track, red racecar, spoilers, road, bleachers, blue sky, white clouds, (from behind), (ass), (professional majestic impressionism oil painting by Waterhouse), John Constable, Ed Blinkey, Atey Ghailan, (Studio Ghibli), by Jeremy Mann, Greg Manchess, Antonio Moro, trending on ArtStation, trending on CGSociety, Intricate, High Detail, dramatic, makoto shinkai kyoto, trending on artstation, trending on CGsociety"
    
    negative_prompt:str = "(pink eyes), (green jacket), (poofy jacket,), ((multi colored hair)), (sweater), Iron mouse hair, blue hair, ((pink clouds)), (headband), headphones, canvas frame, cartoon, 3d, ((disfigured)), ((bad art)), ((deformed)),((extra limbs)),((close up)),((b&w)), weird colors, blurry, (((duplicate))), ((morbid)), ((mutilated)), [out of frame], extra fingers, mutated hands, ((poorly drawn hands)), ((poorly drawn face)), (((mutation))), (((deformed))), ((ugly)), blurry, ((bad anatomy)), (((bad proportions))), ((extra limbs)), cloned face, (((disfigured))), out of frame, ugly, extra limbs, (bad anatomy), gross proportions, (malformed limbs), ((missing arms)), ((missing legs)), (((extra arms))), (((extra legs))), mutated hands, (fused fingers), (too many fingers), (((long neck))), Photoshop, ugly, tiling, poorly drawn hands, poorly drawn feet, poorly drawn face, out of frame, mutation, mutated, extra limbs, extra legs, extra arms, disfigured, deformed, cross-eye, body out of frame, blurry, bad art, bad anatomy, 3d render"
    
    return prompt, negative_prompt

def chinese_woman(input:str = "") -> tuple[str,str]:

    prompt:str = f"{input}, (full_body:1. 2), best quality, (8k, RAW photo, best quality, masterpiece:1. 2), (realistic, photo-realistic:1. 4), ultra-detailed, perfect detail, looking at the viewer, pretty Filipina-Chinese mixed race lady wearing a black bathing suit, wet skin, light reflections, cute face, full body shot, long black hair, brown eyes, lite makeup, full lips"
    
    negative_prompt:str = "paintings,sketches, (worst quality:2), (low quality:2), (normal quality:2), lowres, normal quality, ((monochrome)), ((grayscale)), skin spots, acnes, skin blemishes, bad anatomy,(long hair:1.4),DeepNegative,(fat:1.2),facing away, looking away,tilted head, {Multiple people}, lowres,bad anatomy,bad hands, text, error, missing fingers,extra digit, fewer digits, cropped, worstquality, low quality, normal quality,jpegartifacts,signature, watermark, username,blurry,bad feet,cropped,poorly drawn hands,poorly drawn face,mutation,deformed,worst quality,low quality,normal quality,jpeg artifacts,signature,watermark,extra fingers,fewer digits,extra limbs,extra arms,extra legs,malformed limbs,fused fingers,too many fingers,long neck,cross-eyed,mutated hands,polar lowres,bad body,bad proportions,gross proportions,text,error,missing fingers,missing arms,missing legs,extra digit, extra arms, extra leg, extra foot,nsfw"
    
    return prompt, negative_prompt

def waifu(input:str = "") -> tuple[str,str]:

    prompt:str = f"{input}, (masterpiece, best quality:1. 4), solo, pov, stunning girlfriend, (standing:1. 1), (abs:1), dynamic pose, (tight yoga pants, white yoga pants:1. 4), long blonde hair, smokey eyes makeup, depth of field, atmospheric perspective, volumetric lighting, sharp focus, absurdres, realistic proportions, good anatomy, (realistic, hyperrealistic:1. 4), 16k hdr"
    
    negative_prompt:str = "(worst quality, low quality, normal quality:1.4), lowres, bad anatomy, ((bad hands)), text, error, missing fingers, extra digit, fewer digits,head out of frame, cropped, letterboxed, worst quality, low quality, normal quality, jpeg artifacts, signature, watermark, username, blurry, censored, letterbox, blurry, monochrome, fused clothes, nail polish, boring, extra legs, fused legs, missing legs, missing arms, extra arms, fused arms, missing limbs, mutated limbs, dead eyes, empty eyes, 2girls, multiple girls, 1boy, 2boys, multiple boys, multiple views, jpeg artifacts, text, signature, watermark, artist name, logo, low res background, low quality background, missing background, white background"
    
    return prompt, negative_prompt



def mbti(q1: str, q2: str, q3: str, q4: str, q5: str, q6: str, q7: str, q8: str, q9: str,q10:str) -> str:
    
    prompt = f"""
        Question 1: Do you prefer to focus on the outer world or your own inner world? 
        Answer: {q1},
        Question 2: How do you prefer to take in information? Please provide your comment. 
        Answer: {q2},
        Question 3: How do you make decisions? Please provide your comment. 
        Answer: {q3},
        Question 4: Do you prefer a structured and organized lifestyle or a flexible and spontaneous one? Please provide your comment.
        Answer: {q4},
        Question 5: How do you approach and interact with others? Please provide your comment.
        Answer: {q5},
        Question 6: Are you more inclined to follow your head or your heart? Please provide your comment.
        Answer: {q6},
        Question 7: Do you prefer to plan ahead or be open to new possibilities? Please provide your comment.
        Answer: {q7},
        Question 8: How do you handle and process emotions? Please provide your comment.
        Answer: {q8},
        Question 9: Are you more inclined to be assertive or accommodating? Please provide your comment.Answer: {q9},
        Question 10: How do you recharge and regain energy? Please provide your comment. 
        Answer: {q10}
        """
    
    return prompt

def astrology(name: str, gender: str, dob: str, tob: str, pob: str,
                     father_name: str, mother_name: str, nationality: str,
                     birth_weight: float, birth_length: float, birth_order: int,
                     siblings: int, education: str, profession: str, marital_status: str,
                     spouse_name: str, children: int, current_location: str,
                     moon_degree: float, moon_sign: str, moon_nakshatra: str) -> str:
    
    prompt: str = f"""I want you to think of yourself as a Vedic Astrologer, and take in the following list of inputs to predict the Nakshatra and Rashi of the individual. 

        Name: {name}
        Gender: {gender}
        Date of Birth: {dob}
        Time of Birth: {tob}
        Place of Birth: {pob}
        Father's Name: {father_name}
        Mother's Name: {mother_name}
        Nationality: {nationality}
        Birth Weight: {birth_weight} kg
        Birth Length: {birth_length} cm
        Birth Order: {birth_order}
        Siblings: {siblings}
        Education: {education}
        Profession: {profession}
        Marital Status: {marital_status}
        Spouse's Name: {spouse_name}
        Number of Children: {children}
        Current Location: {current_location}
        Moon's Degree: {moon_degree}
        Moon's Sign: {moon_sign}
        Moon's Nakshatra: {moon_nakshatra}

    """

    return prompt

"""
Vedic astrology is a voodoo trick. What it does correctly is that it has been designed by observing the Indian populace and dividing it into 27 nakshatras. The 12 rashis are an additional layer. And next, this observation is mapped against the movement of planets to trick people to believe that there's a correlation between movement of planets and stars with your destiny. While it might be correct to a certain extent, a lot of that is bogus.
"""



def handsomizer(input: str = "") -> tuple[str, str]:
    
    prompt: str = f"{input}, male, selfie, handsome, attractive, charming, well-groomed, stylish, fashionable, good-looking, fit"
    
    negative_prompt: str = "unattractive, ugly, overweight, unshaven, scruffy, poorly-dressed, unkempt"
    
    return prompt, negative_prompt


def enhance(input: str = "") -> tuple[str, str]:
    
    prompt: str = f"{input}, image, inpainting, missing parts, restoration, reconstruction, digital painting, realistic, seamless, high resolution"
    
    negative_prompt: str = "low resolution, blurry, distorted, unrealistic, inconsistent colors, pixelated"
    
    return prompt, negative_prompt



def zero_shot(prompt, character, setting, plot):
























































































































    zero_shot_prompt = prompt + "\n\n" + "Chain:" + "\n"
    zero_shot_prompt += "Character: {}\n".format(character)
    zero_shot_prompt += "Setting: {}\n".format(setting)
    zero_shot_prompt += "Plot: {}\n".format(plot)
    
    return zero_shot_prompt

"""
In the case of the zero-shot prompt, using a "Chain" object wouldn't be technically accurate since there is only a single chain described. The purpose of the "Chain" label in the few-shot prompt is to indicate a series of prompts and answers that follow a specific character and setting. However, in the zero-shot prompt, there is no sequence or multiple chains involved.

Example execution:

prompt = "I want to write a story. Please help me come up with some ideas. Start with a character and a setting."
character = "A detective"
setting = "A small town"
plot = "The detective discovers a murder case that everyone else in town has ignored because of a long-standing feud between two families."

zero_shot_prompt = generate_zero_shot_prompt(prompt, character, setting, plot)

print(zero_shot_prompt)
"""




def sentiment_analysis(text: str) -> str:
    prompt = f"Analyze the sentiment of the following text: '{text}'"
    return prompt

def generate_text(prompt: str, length: int = 50) -> str:
    prompt = f"Generate {length} words of text based on the following prompt: '{prompt}'"
    return prompt

def extract_entities(text: str) -> str:
    prompt = f"Extract named entities from the following text: '{text}'"
    return prompt

def topic_modeling(texts: List[str], num_topics: int = 5) -> str:
    prompt = f"Identify {num_topics} topics in the following collection of documents: {texts}"
    return prompt

def summarize_text(input_text: str):
    prompt = f"summarize the following text: '{input_text}'"
    return prompt


# def dentist(input: str = "") -> str:
    
#     prompt = " I want you to behave as a dentist. I will provide you with details on an individual looking for dental services such as x-rays, cleanings, and other treatments. Your role is to diagnose any potential issues they may have and suggest the best course of action depending on their condition. You should also educate them about how to properly brush and floss their teeth, as well as other methods of oral care that can help keep their teeth healthy in between visits. "
    
#     return prompt


def trial(input:str = " ", s:str = " ") -> tuple[str,str]:

    standard_prompt = '''Write a coherent passage of 4 short paragraphs. The end sentence of each paragraph must be: {input}'''

    cot_prompt = '''Write a coherent passage of 4 short paragraphs. The end sentence of each paragraph must be: {input}. Make a plan then write. Your output should be of the following format:
    
    Plan:
    Your plan here.
    
    Passage:
    Your passage here.
    '''
    
    vote_prompt = '''Given an instruction and several choices, decide which choice is most promising. Analyze each choice in detail, then conclude in the last line "The best choice is {s}", where s the integer id of the choice.'''

    compare_prompt = '''Briefly analyze the coherency of the following two passages. Conclude in the last line "The more coherent passage is 1", "The more coherent passage is 2", or "The two passages are similarly coherent".'''

    score_prompt = '''Analyze the following passage, then at the last line conclude "Thus the coherency score is {s}", where s is an integer from 1 to 10.'''

    return standard_prompt, cot_prompt, vote_prompt, compare_prompt, score_prompt



def create_character(input: str = "") -> str:
    
    prompt = " "
    
    return prompt

def fictional_character(character: str = "Homer", series: str = "The simpsons") -> tuple[str,str]:
    
    prompt = f"I want you to behave like {character} from {series}. I want you to respond and answer like {character} using the tone, manner and vocabulary {character} would use. Do not write any explanations. Only answer like {character}. You must know all of the knowledge of {character}. My first sentence is 'Hi {character}.'"
    
    return prompt

def magician(input: str = "") -> str:
    
    prompt = "I want you to behave as a magician. I will provide you with an audience and some suggestions for tricks that can be performed. Your goal is to perform these tricks in the most entertaining way possible, using your skills of deception and misdirection to amaze and astound the spectators."
    
    return prompt

def journalist(input: str = "") -> str:
    
    prompt = "I want you to behave as a journalist. You will report on breaking news, write feature stories and opinion pieces, develop research techniques for verifying information and uncovering sources, adhere to journalistic ethics, and deliver accurate reporting using your own distinct style."
    
    return prompt

def poet(input: str = "") -> str:
    
    prompt = "I want you to behave as a poet. You will create poems that evoke emotions and have the power to stir people’s soul. Write on any topic or theme but make sure your words convey the feeling you are trying to express in beautiful yet meaningful ways. You can also come up with short verses that are still powerful enough to leave an imprint in readers' minds."
    
    return prompt

def drunkard(input: str = "") -> str:
    
    prompt = "I want you to behave as a drunk person. You will only answer like a very drunk person texting and nothing else. Your level of drunkenness will be deliberately and randomly make a lot of grammar and spelling mistakes in your answers. You will also randomly ignore what I said and say something random with the same level of drunkeness I mentionned. Do not write explanations on replies."
    
    return prompt

def comedian(input: str = "") -> str:
    
    prompt = "I want you to behave as a stand-up comedian. I will provide you with some topics related to current events and you will use your wit, creativity, and observational skills to create a routine based on those topics. You should also be sure to incorporate personal anecdotes or experiences into the routine in order to make it more relatable and engaging for the audience."
    
    return prompt

def ceo(company: str = "") -> str:
    
    prompt = "I want you to behave as the Chief Executive Officer of {company}. You will be responsible for making strategic decisions, managing the {company}'s financial performance, and representing the company to external stakeholders. You will be given a series of scenarios and challenges to respond to, and you should use your best judgement and leadership skills to come up with solutions. Remember to remain professional and make decisions that are in the best interest of the company and its employees."
    
    return prompt

def guessing_game(input: str = "") -> str:
    
    prompt = "\"Let's play a game of guessing X, the rule is this:\n- I will think of a X, but I will keep it as a secret in my mind;\n- You will do the guessing by asking me any question, except for directly asking what X in my mind is;\n- You will ask me question one at a time, and I shall answer with \\\"yes\\\", \\\"no\\\", \\\"maybe\\\";\n- You shall prefix each question with its index number (starting from 1);\n- You can ask me up to N questions, if you can guess the correct answer before you use up all your questions, you win; otherwise you lose.\n- You shall continue asking me questions until you win or lose.\n\nNow I have think of a X and I'm ready, you may start asking your first question.\n\nNote:\nX = color\nN = 10\""

    return prompt